package com.yanzhu.jh.project.service;

import java.util.List;
import java.util.Map;

import com.yanzhu.jh.project.domain.SurProjectInsurance;

/**
 * 项目保险Service接口
 * 
 * @author JiangYuQi
 * @date 2023-08-16
 */
public interface ISurProjectInsuranceService 
{
    /**
     * 查询项目保险
     * 
     * @param id 项目保险主键
     * @return 项目保险
     */
    public SurProjectInsurance selectSurProjectInsuranceById(Long id);

    /**
     * 查询项目保险列表
     * 
     * @param surProjectInsurance 项目保险
     * @return 项目保险集合
     */
    public List<SurProjectInsurance> selectSurProjectInsuranceList(SurProjectInsurance surProjectInsurance);

    /**
     * 查询项目保险列表
     *
     * @param surProjectInsurance 项目保险
     * @return 项目保险集合
     */
    public List<SurProjectInsurance> selectSurProjectInsuranceListv2(SurProjectInsurance surProjectInsurance);

    /**
     * 查询大屏保险统计列表
     *
     * @param surProjectInsurance 项目保险
     * @return map集合
     */
    public List<Map<String,Object>> selectBgscreenInsuranceList(SurProjectInsurance surProjectInsurance);

    /**
     * 新增项目保险
     * 
     * @param surProjectInsurance 项目保险
     * @return 结果
     */
    public int insertSurProjectInsurance(SurProjectInsurance surProjectInsurance);

    /**
     * 修改项目保险
     * 
     * @param surProjectInsurance 项目保险
     * @return 结果
     */
    public int updateSurProjectInsurance(SurProjectInsurance surProjectInsurance);

    /**
     * 批量删除项目保险
     * 
     * @param ids 需要删除的项目保险主键集合
     * @return 结果
     */
    public int deleteSurProjectInsuranceByIds(Long[] ids);

    /**
     * 删除项目保险信息
     * 
     * @param id 项目保险主键
     * @return 结果
     */
    public int deleteSurProjectInsuranceById(Long id);

    /**
     * 按项目获取保险信息
     * @param id
     * @return
     */
    public List<SurProjectInsurance> selectProjectInsuranceListByProjectId(Long id);
}
